#line 2 "bisonflex/cmdoptions.yy.cpp"

#line 4 "bisonflex/cmdoptions.yy.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer cmdoptionsFlexLexer
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
/* %endif */

/* %if-c++-only */
	std::istream* yy_input_file;
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */
/* %if-not-reentrant */
/* %not-for-header */

/* %ok-for-header */

/* %endif */
/* %endif */

void *cmdoptionsalloc (yy_size_t  );
void *cmdoptionsrealloc (void *,yy_size_t  );
void cmdoptionsfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include "../win_include/FlexLexer.h"

int yyFlexLexer::yywrap() { return 1; }
int yyFlexLexer::yylex()
	{
	LexerError( "yyFlexLexer::yylex invoked but %option yyclass used" );
	return 0;
	}

#define YY_DECL int FlexScanner::yylex()

/* %if-c-only Standard (non-C++) definition */
/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 209
#define YY_END_OF_BUFFER 210
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1186] =
    {   0,
        0,    0,  210,  208,  206,  207,  204,  208,   38,  203,
      203,  204,  202,  202,   37,  202,  203,  203,  203,  203,
      202,  202,  202,  202,  202,  202,  203,  203,    7,  203,
      203,  203,  203,  107,  108,  203,  203,  203,  203,  203,
      109,  203,  203,  206,  207,  204,    0,    0,  203,  203,
      203,  203,  203,  203,  203,  203,  100,  203,  203,  203,
        6,    8,   84,  203,  203,  203,    9,  203,    1,  204,
      202,  203,    0,  203,  203,  203,  202,   90,  202,  203,
      203,  203,  202,   86,  203,  203,  203,  203,  203,  202,
      203,  203,  202,  202,  202,  203,  203,  203,  202,  203,

      203,  203,  203,  203,  203,  203,  203,  141,   88,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,   10,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  205,    0,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,    0,    2,  204,    3,    0,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,

       32,  203,  203,  203,  203,  203,  202,  203,  203,  203,
      203,  203,  203,  202,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,   87,  203,
      203,  203,  203,  203,  203,   64,  203,  119,   31,  203,
      203,  203,  203,   11,  203,  203,  203,  203,  203,  203,
      203,  199,   57,   89,  163,  203,   41,  203,  203,  203,
      203,  203,  203,  203,  203,  203,   58,  203,  203,  147,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,    0,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,

      203,   12,  203,  203,  203,  203,  203,  203,  203,   47,
      203,  203,  203,  203,  203,  203,  203,  203,   23,   27,
      203,  203,  203,  203,  103,   56,  203,  203,  203,  203,
      203,  203,  203,  203,  136,  137,  203,  203,  203,  203,
      203,  129,  203,  203,  203,  203,  203,  203,  203,  203,
      140,  106,   76,  203,  203,  203,  203,   24,  203,  203,
       15,  150,   28,  203,  203,  203,  203,  176,  203,  144,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  128,  203,  203,  203,  203,  203,  203,  203,  203,

      203,  203,  203,  203,  203,  203,  148,  203,  203,  203,
      203,  203,  203,   73,   72,  203,  203,  203,  203,   40,
      203,  203,  203,    5,  203,  101,  203,  203,  203,  203,
      203,  203,  203,  203,  203,   85,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,   21,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
       16,  203,  203,  203,  203,  203,  203,   61,   22,  203,
      203,   13,  203,  203,  203,  203,  203,  192,  203,  105,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  168,  203,  203,  203,  203,  203,  203,  203,  203,

      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  194,  203,  203,  203,  203,  203,   17,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,   39,  203,  203,  203,  203,  203,  203,    4,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
       29,   99,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  188,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  149,
       80,  112,  203,  203,  203,  203,  174,  203,  203,  203,

      203,  203,  203,  203,  203,  203,  161,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  151,  203,
      203,  124,   75,  203,  203,   74,  203,  203,  203,  203,
      203,  203,  203,  203,  203,   48,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,   93,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  116,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,

      203,  203,  203,  203,  203,  203,  203,  203,  203,   42,
      203,  153,  170,  203,  154,  203,   45,  175,  203,  203,
      203,  155,  203,  156,   36,  203,  177,  165,  203,  203,
      203,  203,  203,  203,  203,   14,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,   20,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
       25,  203,  203,  203,  203,  203,  203,  203,  203,  102,
      203,  203,  203,  203,  203,  203,  203,  167,  203,  203,
      203,  203,  203,  130,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,

      203,  203,  203,  203,  203,  203,  132,  203,  203,  203,
       35,  203,  203,  203,  203,  203,  196,  203,  203,  203,
      203,   26,  203,  203,  171,  198,  203,  203,  203,  172,
      203,  203,   18,  203,  203,   46,  203,  203,  203,  203,
      203,  203,  203,   98,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  173,  203,  203,  189,  203,
      203,  203,  203,  203,  203,  159,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
       60,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  146,  145,

      203,  203,  203,  203,  203,   83,  203,   78,  184,  203,
      203,   77,  120,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,   96,  203,  152,  203,  203,  186,  203,  134,  203,
      203,   43,  160,  203,  203,  139,  203,  203,  203,  203,
       62,   63,  203,  203,  162,  203,  203,  203,  203,  203,
       67,  203,  201,  203,   81,   65,  203,  143,  122,  203,
      203,  203,  203,  203,  203,  200,  203,  203,  203,   44,
      203,  203,  125,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,   69,  203,  203,  203,  203,  203,

      203,  203,   92,  203,  185,  203,  193,  135,  180,  195,
      203,  203,  203,  203,  203,  203,  203,  203,  203,  179,
      203,  203,  203,  203,  203,  203,  203,  203,  131,  115,
      203,  203,  187,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  203,  203,  203,  203,   97,   71,
      203,  203,  203,   19,  203,  133,  203,  203,  203,  203,
      197,  203,  203,  110,  203,  203,  203,  203,  203,  203,
       68,  203,   66,  203,  166,  203,  203,  203,  203,   82,
      114,  203,  203,  203,  203,   50,   51,  203,  203,  203,
      203,   95,  203,  203,  203,   70,  203,  203,  138,  203,

      203,  203,  191,  203,  203,  203,  203,  117,  203,  203,
       59,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,   55,  203,  203,  203,  203,  164,  203,  203,
      118,  203,  203,  203,  203,  203,  203,  113,  203,  203,
      203,   79,  203,   34,   33,  203,  203,  203,   49,  203,
      203,  203,  181,  203,  104,  123,  183,  111,  158,  203,
      169,  203,  203,  203,   91,   94,   52,  203,  203,  203,
      203,  203,  203,  126,  203,  203,   53,  127,  203,  178,
      121,   54,   30,  182,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    5,    5,    5,    5,    1,    5,
        5,    7,    5,    8,    9,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   20,   21,   22,    1,    1,
       23,    1,    1,    5,   24,   25,   26,   27,   27,   27,
       28,   29,   28,   28,   30,   28,   31,   28,   28,   28,
       28,   28,   32,   28,   28,   28,   28,   33,   28,   28,
        1,   34,    1,    5,   35,    1,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   51,   52,   53,   54,   55,   56,   57,   58,   59,
       60,   61,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    1,    1,    2,    3,    4,    1,    5,    6,    6,
        3,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    1,    1,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    3,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6
    } ;

static yyconst flex_int16_t yy_base[1192] =
    {   0,
        0,    0, 1420, 1421,   60, 1416,    0,   61,    0,   92,
      118,   56,  168,   35, 1421,  141, 1396,   61,   47,  142,
      177,  198,  169,  181,  217,  227,  156,  221,  225,  176,
      255,  216,  257,  260,  297,  240,  245,  268,  250,  189,
       62,   71,  224,   84, 1414,    0, 1410,  212,    0,    0,
      169, 1371,  258,   50, 1370, 1373, 1372, 1363,  116, 1360,
       33,  274, 1369,  262, 1361, 1367,    0, 1346, 1421,  353,
      193,  365,  304, 1381, 1344, 1367,  290,  287,  293, 1358,
     1363, 1345,  309,  277,  283, 1349, 1348, 1357,  283,  360,
     1360,  322,  341,  376,  339,  327, 1342, 1356,  340, 1346,

     1350, 1354, 1341, 1353, 1331, 1351, 1332,    0, 1330, 1348,
      323, 1323, 1328, 1339, 1326,  374, 1325, 1323, 1329, 1327,
     1334, 1333,    0, 1318, 1317, 1331, 1321,  373, 1316, 1320,
     1312, 1327,  348,  375, 1319,  289, 1318, 1322,  382, 1326,
     1323,  372,  381, 1314, 1323, 1310, 1310,  134, 1305, 1314,
     1314, 1300, 1299, 1300, 1301, 1421,  409, 1311, 1293, 1306,
     1309,  385, 1289,  333, 1297, 1294, 1295, 1305, 1298, 1297,
      388, 1283, 1297,  249, 1286, 1294, 1298,  384,  383, 1296,
     1279, 1282, 1327, 1421,  443,    0,    0, 1303, 1316, 1274,
     1288, 1279, 1282, 1280, 1279, 1285, 1274, 1275, 1283, 1282,

        0, 1278, 1260, 1276, 1253, 1272,  399, 1275, 1255, 1271,
     1261, 1256, 1259,  405, 1251, 1267, 1250, 1252, 1261, 1256,
      204, 1263, 1251, 1257, 1257, 1255, 1256, 1284,    0, 1250,
     1241, 1235,  422, 1235, 1252, 1278, 1247,    0,    0, 1249,
     1244, 1246, 1226, 1227, 1236, 1244, 1225, 1237, 1230, 1231,
      412, 1239,    0,    0,    0, 1237,    0, 1237, 1230, 1229,
     1215, 1230, 1226, 1231, 1226, 1224,    0, 1207, 1205,    0,
     1208,  399, 1216, 1218,  403, 1221, 1210, 1218, 1201, 1214,
     1218, 1199,  416, 1202, 1215, 1197, 1242, 1204, 1203, 1210,
     1188, 1196, 1191, 1187, 1203, 1186, 1191, 1197, 1185, 1193,

     1198,    0, 1177, 1195, 1196, 1177, 1183, 1184, 1189,    0,
     1187, 1169, 1170, 1169, 1178, 1177, 1176, 1167,    0,    0,
     1163, 1174, 1176, 1166,    0,  422, 1166, 1173, 1170, 1168,
     1170, 1163,  428, 1162,    0,    0, 1165, 1146, 1161, 1156,
     1168, 1167, 1141, 1164, 1159, 1151, 1137, 1143, 1144, 1147,
        0,    0,    0, 1158, 1139, 1151, 1152,    0, 1135, 1148,
        0,    0,    0, 1134, 1146, 1147, 1130,    0, 1140,    0,
     1132, 1127, 1140, 1129, 1123, 1130, 1123, 1139, 1126, 1126,
     1123, 1127, 1122, 1114, 1130, 1109, 1122, 1121, 1124, 1119,
      420,    0, 1109, 1108, 1120, 1104, 1114, 1113, 1101, 1111,

     1108, 1098, 1102, 1095, 1110, 1094,    0,  440, 1102, 1106,
     1110, 1101, 1096, 1095,    0, 1102, 1098, 1098, 1104, 1103,
     1097, 1089, 1075,    0, 1081,    0, 1093, 1094, 1076, 1080,
     1074, 1081, 1091, 1078, 1085,    0, 1071, 1063, 1078, 1066,
     1071, 1078, 1070, 1091, 1101, 1055, 1066, 1062, 1063,    0,
     1051, 1061, 1069, 1059, 1053,  442, 1058, 1055, 1064, 1049,
        0, 1067, 1052, 1065, 1047, 1059, 1062, 1087, 1044, 1054,
     1042,    0, 1037, 1031, 1052, 1053, 1035,    0, 1044, 1032,
     1047, 1035, 1023, 1039, 1041, 1030, 1041, 1023, 1028, 1016,
     1039,    0, 1032, 1037, 1025, 1016, 1015, 1025, 1032, 1028,

     1031, 1018, 1022, 1009, 1015, 1017, 1021, 1002, 1018, 1022,
     1020, 1008, 1012,    0, 1006, 1012,  430, 1001,  997,    0,
      988, 1005, 1011, 1006,  985,  997,  994,  992,  990,  991,
      999,    0,  432,  999,  986,  996,  984,  998,    0,  973,
      989,  981,  970,  993,  986,  991,  972,  985,  975,  981,
        0,    0,  962,  970,  995, 1005,  977,  977,  980,  960,
      452,  978,  966,  973,    0,  961,  970,  965,  972,  971,
      968,  949,  426,  968,  963,  948,  957,  957,  948,  947,
      962,  941,  951,  948,  943,  937,  937,  954,  934,  953,
      952,    0,  950,  949,  929,  947,    0,  946,  930,  920,

      939,  936,  937,  941,  931,  925,    0,  923,  928,  931,
      921,  915,  928,  920,  922,  925,  925,  912,  913,  921,
      911,  919,  919,  920,  905,  900,  910,  903,    0,  897,
      891,  915,  439,  907,  909,  907,  891,  898,  890,  889,
      898,  438,  906,  885,  884,    0,  901,  882,  885,  875,
      894,  891,  878,  892,  892,  880,  893,  887,  887,  871,
      861,  852,  847,   41,   70,  133,  168,  208,  239,  273,
      309,  376,  400,  415,  423,  442,  455,  442,  440,  447,
      446,  445,  463,  485,  455,  467,  460,  455,  466,  458,
      468,  465,  496,  461,  472,  474,  500,  476,  472,  462,

      471,  479,  485,  472,  482,  476,  480,  475,  487,    0,
      479,    0,    0,  493,    0,  489,    0,    0,  490,  492,
      476,    0,  497,    0,    0,  496,    0,    0,  496,  487,
      501,  484,  493,  526,  501,    0,  503,  490,  501,  496,
      497,  498,  497,  505,  511,  517,  510,  515,  509,  513,
      518,  524,  511,  521,  527,  523,  523,  529,  520,  513,
        0,  520,  522,  515,  535,  534,  516,  527,  519,    0,
      540,  536,  534,  539,  540,  541,  532,    0,  534,  548,
      541,  550,  543,    0,  539,  569,  576,  554,  536,  543,
      545,  535,  555,  562,  556,  582,  560,  548,  553,  556,

      587,  565,  566,  558,  568,  570,    0,  572,  575,  569,
        0,  574,  565,  575,  580,  580,    0,  581,  575,  569,
      566,    0,  582,  583,    0,    0,  585,  568,  571,    0,
      614,  590,    0,  585,  586,    0,  594,  595,  577,  584,
      600,  586,  588,    0,  600,  603,  597,  604,  605,  596,
      589,  606,  633,  597,  608,    0,  601,  614,    0,  611,
      599,  604,  610,  617,  602,    0,  604,  605,  620,  621,
      611,  625,  628,  625,  649,  653,  623,  613,  620,  635,
        0,  627,  629,  624,  656,  662,  637,  640,  658,  662,
      667,  629,  641,  645,  649,  647,  639,  648,    0,  654,

      631,  649,  648,  637,  640,  648,  640,    0,    0,  656,
      658,    0,    0,  663,  665,  666,  658,  659,  649,  656,
      663,  669,  666,  671,  663,  672,  669,  658,  679,  660,
      676,    0,  679,    0,  665,  665,    0,  681,    0,  680,
      683,    0,    0,  670,  675,    0,  677,  680,  680,  679,
        0,    0,  675,  688,  697,  686,  692,  699,  696,  701,
        0,  721,    0,  686,    0,    0,  723,    0,    0,  695,
      687,  693,  704,  709,  696,    0,  707,  693,  707,    0,
      694,  698,    0,  717,  698,  706,  707,  701,  702,  715,
      724,  724,  721,  716,    0,  713,  724,  729,  711,  725,

      726,  716,    0,  730,    0,  731,    0,    0,    0,    0,
      731,  738,  734,  726,  736,  724,  744,  741,  741,    0,
      728,  723,  729,  767,  726,  769,  748,  753,    0,    0,
      751,  733,    0,  738,  749,  740,  755,  782,  757,  748,
      749,  746,  747,  767,  764,  750,  745,  752,    0,    0,
      768,  754,  765,    0,  770,    0,  772,  762,  772,  776,
        0,  777,  776,    0,  768,  763,  763,  778,  768,  767,
        0,  773,    0,  765,    0,  786,  778,  773,  781,    0,
        0,  773,  792,  793,  794,    0,    0,  784,  779,  793,
      783,    0,  798,  784,  792,    0,  796,  793,    0,  792,

      804,  805,    0,  795,  799,  808,  809,    0,  797,  796,
        0,  799,  813,  801,  819,  808,  812,  818,  819,  809,
      813,  822,    0,  810,  811,  829,  811,    0,  811,  811,
        0,  814,  819,  824,  818,  833,  830,    0,  822,  836,
      835,    0,  823,    0,    0,  824,  829,  827,    0,  842,
      841,  848,    0,  841,    0,    0,    0,    0,    0,  836,
        0,  851,  848,  853,    0,    0,    0,  854,  851,  850,
      855,  845,  847,    0,  854,  849,    0,    0,  858,    0,
        0,    0,    0,    0, 1421,  896,  901,  903,  908,  914,
      920

    } ;

static yyconst flex_int16_t yy_def[1192] =
    {   0,
     1185,    1, 1185, 1185, 1185, 1185, 1186, 1187, 1188, 1185,
       10, 1186,   11,   13, 1185,   13,   11,   11,   11,   11,
       13,   13,   13,   13,   13,   13,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11, 1185, 1185, 1186, 1189, 1189, 1188,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11, 1185, 1190,
       13,   11, 1185,   11,   11,   11,   13,   13,   13,   11,
       11,   11,   13,   11,   11,   11,   11,   11,   11,   13,
       11,   11,   13,   13,   13,   11,   11,   11,   13,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11, 1185, 1185,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11, 1191, 1185, 1190,   72, 1186,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   13,   11,   11,   11,
       11,   11,   11,   13,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11, 1189,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,    0, 1185, 1185, 1185, 1185, 1185,
     1185

    } ;

static yyconst flex_int16_t yy_nxt[1483] =
    {   0,
        4,    5,    6,    5,    7,    8,    4,    9,   10,   11,
       12,   13,   14,   14,   14,   14,   14,   14,   14,   14,
       14,    4,   15,   16,   16,   16,   16,   17,   18,   19,
       17,   20,   17,    7,   11,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   17,   30,   31,   32,   33,   34,
       35,   17,   36,   37,   38,   39,   40,   41,   42,   17,
       43,   44,   69,   44,   47,   47,   70,   50,   73,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   73,   73,  766,   44,   75,   44,  172,  173,
      163,   74,   73,   50,   47,   47,   46,  153,  164,   49,

       50,   50,   46,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   50,  767,  154,   50,   50,   50,   50,   50,
       50,   50,   50,   50,   50,   46,   50,   51,   52,   50,
       53,   54,   55,   56,   57,   58,   50,   50,   59,   50,
       60,   61,   62,   50,   63,   64,   65,   50,   66,   67,
       50,   50,   68,   50,   50,  169,   50,   50,   50,   50,
       50,   50,   73,   73,   50,  170,   50,   50,   50,  278,
       50,   50,   50,   50,   50,   50,  768,   73,   50,   71,
       71,   71,   71,   71,   71,   71,   71,   71,   71,  279,
       73,   71,   71,   71,   71,  103,   76,   73,   73,   50,

       72,   50,   73,   71,   71,   71,   71,   71,   71,   50,
       73,   88,   77,   50,   78,  112,   79,  156,   89,   73,
       90,  158,  769,   80,  159,   50,   72,   50,  152,   81,
       50,   91,   82,  157,   83,   50,   92,   73,   73,   50,
       84,   85,   73,  351,   86,   73,   73,   87,   73,   50,
      352,   50,   93,  117,   94,  118,   50,   95,  770,   50,
      104,   73,   99,  108,  105,   96,   73,  109,  106,   97,
      100,   73,  110,  111,  107,   98,   73,  101,   73,  139,
      102,   73,  771,  155,  141,   50,  307,  308,  150,   73,
      113,  142,  119,  140,  114,  143,  121,  161,  144,  145,

      122,  178,  115,  151,  116,  146,  120,  147,  123,  174,
      124,  197,  179,  162,  187,  125,  126,  127,   73,   50,
      148,  772,   50,  199,  200,   50,  175,  149,  261,  176,
      198,  201,  128,  205,  129,  206,  130,  187,  262,  131,
      132,   50,  191,  133,  134,   50,  192,  135,   50,  136,
      137,   50,  138,  183,  183,  184,  183,  211,  183,  183,
      183,  196,  216,  231,  217,  773,  232,   50,  295,  212,
      296,   50,   50,   50,  183,  183,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  186,  256,  220,  186,  186,
      186,  186,   50,  213,  215,  257,  207,   50,   50,   50,

      186,  186,  186,  186,  186,  186,  208,  269,   50,  237,
      249,  250,  258,  209,  214,  238,  271,  265,   50,  287,
      292,  312,  774,  303,  270,  251,  272,  273,  314,  315,
      259,   50,  293,  363,   50,  266,  304,   50,  313,  397,
      401,  775,  287,  183,  183,  184,  183,  380,  183,  183,
      183,  381,  398,  776,  337,  402,  448,   50,  344,  410,
      506,  449,  456,   50,  183,  183,  382,  624,  677,  411,
      507,  457,  678,  734,  458,  364,  522,  777,  523,  566,
      567,  639,  568,  640,  459,  625,  665,  735,  744,  778,
      779,  780,  666,  745,  781,  782,  783,  784,  785,  786,

      788,  787,  789,  790,  791,  792,  793,  794,  795,  796,
      798,  799,  800,  801,  803,  804,  805,  806,  807,  808,
      809,  810,  811,  812,  813,  814,  815,  816,  817,  818,
      819,  820,  821,  822,  823,  824,  825,  826,  827,  828,
      829,  797,  830,  831,  832,  802,  833,  834,  835,  836,
      837,  838,  839,  840,  841,  842,  843,  844,  845,  846,
      847,  848,  849,  850,  851,  852,  853,  854,  855,  856,
      857,  858,  859,  860,  861,  862,  863,  864,  865,  866,
      867,  868,  869,  870,  871,  872,  873,  874,  875,  876,
      877,  878,  879,  880,  881,  882,  883,  884,  885,  886,

      887,  888,  889,  890,  891,  892,  893,  894,  895,  896,
      897,  898,  899,  900,  901,  902,  903,  904,  905,  906,
      907,  908,  909,  910,  911,  912,  913,  914,  915,  916,
      917,  918,  919,  920,  921,  922,  923,  924,  925,  926,
      927,  928,  929,  930,  931,  932,  933,  934,  935,  936,
      937,  938,  939,  940,  941,  942,  943,  944,  945,  946,
      947,  948,  949,  950,  951,  952,  953,  954,  955,  956,
      957,  958,  960,  961,  959,  962,  963,  964,  965,  966,
      967,  968,  969,  970,  971,  972,  973,  974,  975,  976,
      977,  978,  979,  980,  981,  982,  983,  984,  985,  986,

      987,  988,  989,  990,  991,  992,  994,  995,  993,  996,
      997,  998,  999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
     1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016,
     1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026,
     1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036,
     1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046,
     1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056,
     1057, 1059, 1060, 1061, 1058, 1062, 1063, 1064, 1065, 1066,
     1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076,
     1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086,

     1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096,
     1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106,
     1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116,
     1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125, 1126,
     1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135, 1136,
     1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145, 1146,
     1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156,
     1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166,
     1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176,
     1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184,   46,  765,

      764,   46,   48,   48,  763,  762,   48,   49,   49,   47,
       47,   47,  761,   47,  185,  185,  185,  185,  185,  185,
      183,  183,  183,  183,  183,  183,  760,  759,  758,  757,
      756,  755,  754,  753,  752,  751,  750,  749,  748,  747,
      746,  743,  742,  741,  740,  739,  738,  737,  736,  733,
      732,  731,  730,  729,  728,  727,  726,  725,  724,  723,
      722,  721,  720,  719,  718,  717,  716,  715,  714,  713,
      712,  711,  710,  709,  708,  707,  706,  705,  704,  703,
      702,  701,  700,  699,  698,  697,  696,  695,  694,  693,
      692,  691,  690,  689,  688,  687,  686,  685,  684,  683,

      682,  681,  680,  679,  676,  675,  674,  673,  672,  671,
      670,  669,  668,  667,  664,  663,  662,  661,  660,  659,
      658,  657,  656,  655,  654,  653,  652,  651,  650,  649,
      648,  647,  646,  645,  644,  643,  642,  641,  638,  637,
      636,  635,  634,  633,  632,  631,  630,  629,  628,  627,
      626,  623,  622,  621,  620,  619,  618,  617,  616,  615,
      614,  613,  612,  611,  610,  609,  608,  607,  606,  605,
      604,  603,  602,  601,  600,  599,  598,  597,  596,  595,
      594,  593,  592,  591,  590,  589,  588,  587,  586,  585,
      584,  583,  582,  581,  580,  579,  578,  577,  576,  575,

      574,  573,  572,  571,  570,  569,  565,  564,  563,  562,
      561,  560,  559,  558,  557,  556,  555,  554,  553,  552,
      551,  550,  549,  548,  547,  546,  545,  544,  543,  542,
      541,  540,  539,  538,  537,  536,  535,  534,  533,  532,
      531,  530,  529,  528,  527,  526,  525,  524,  521,  520,
      519,  518,  517,  516,  515,  514,  513,  512,  511,  510,
      509,  508,  505,  504,  503,  502,  501,  500,  499,  498,
      497,  496,  495,  494,  493,  492,  491,  490,  489,  488,
      487,  486,  485,  484,  483,  482,  481,  480,  479,  478,
      477,  476,  475,  474,  473,  472,  471,  470,  469,  468,

      467,  466,  465,  464,  463,  462,  461,  460,  455,  454,
      453,  452,  451,  450,  447,  446,  445,  444,  443,  442,
      441,  440,  439,  438,  437,  436,  435,  434,  433,  432,
      431,  430,  429,  428,  427,  426,  425,  424,  423,  422,
      421,  420,  419,  418,  417,  416,  415, 1185,  414,  413,
      412,  409,  408,  407,  406,  405,  404,  403,  400,  399,
      396,  395,  394,  393,  392,  391,  390,  389,  388,  387,
      386,  385,  384,  383,  379,  378,  377,  376,  375,  374,
      373,  372,  371,  370,  369,  368,  367,  366,  365,  362,
      361,  360,  359,  358,  357,  356,  355,  354,  353,  350,

      349,  348,  347,  346,  345,  343,  342,  341,  340,  339,
      338,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  319,  184,
      318,  317,  316,  311,  310,  309,  306,  305,  302,  301,
      300,  299,  298,  297,  294,  291,  290,  289,  288,  286,
      285,  284,  283,  282,  281,  280,  277,  276,  275,  274,
      268,  267,  264,  263,  260,  255,  254,  253,  252,  248,
      247,  246,  245,  244,  243,  242,  241,  240,  239,  236,
      235,  234,  233,  230,  229,  228,  227,  226,  225,  224,
      223,  222,  221,  219,  218,  210,  204,  203,  202,  195,

      194,  193,  190,  189,  188,  182,  181,  180,  177,  171,
      168,  167,  166,  165,  160,  156,   45,   73,   45, 1185,
        3, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185
    } ;

static yyconst flex_int16_t yy_chk[1483] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,   12,    5,    8,    8,   12,   14,   19,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,   18,   41,  664,   44,   19,   44,   61,   61,
       54,   18,   42,   14,    8,    8,   10,   41,   54,   10,

       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,  665,   42,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   11,   11,   59,   11,   11,   11,   11,
       11,   11,   16,   20,   11,   59,   11,   11,   11,  148,
       11,   11,   11,   16,   11,   11,  666,   27,   11,   13,
       13,   13,   13,   13,   13,   13,   13,   13,   13,  148,
       23,   13,   13,   13,   13,   27,   20,   30,   21,   16,

       13,   23,   24,   13,   13,   13,   13,   13,   13,   21,
       40,   23,   21,   24,   21,   30,   21,   48,   23,   22,
       24,   51,  667,   21,   51,   71,   13,   23,   40,   21,
       22,   24,   21,   48,   22,   21,   24,   32,   25,   24,
       22,   22,   28,  221,   22,   43,   29,   22,   26,   25,
      221,   71,   25,   32,   25,   32,   22,   25,  668,   26,
       28,   36,   26,   29,   28,   25,   37,   29,   28,   25,
       26,   39,   29,   29,   28,   25,   31,   26,   33,   36,
       26,   34,  669,   43,   37,   26,  174,  174,   39,   38,
       31,   37,   33,   36,   31,   37,   34,   53,   37,   37,

       34,   64,   31,   39,   31,   38,   33,   38,   34,   62,
       34,   84,   64,   53,   73,   34,   34,   34,   35,   78,
       38,  670,   77,   85,   85,   79,   62,   38,  136,   62,
       84,   85,   35,   89,   35,   89,   35,   73,  136,   35,
       35,   83,   77,   35,   35,   78,   79,   35,   77,   35,
       35,   79,   35,   70,   70,   70,   70,   92,   70,   70,
       70,   83,   96,  111,   96,  671,  111,   83,  164,   92,
      164,   95,   99,   93,   70,   70,   72,   72,   72,   72,
       72,   72,   72,   72,   72,   72,  133,   99,   72,   72,
       72,   72,   90,   93,   95,  133,   90,   95,   99,   93,

       72,   72,   72,   72,   72,   72,   90,  142,   94,  116,
      128,  128,  134,   90,   94,  116,  143,  139,   90,  157,
      162,  178,  672,  171,  142,  128,  143,  143,  179,  179,
      134,  207,  162,  233,   94,  139,  171,  214,  178,  272,
      275,  673,  157,  185,  185,  185,  185,  251,  185,  185,
      185,  251,  272,  674,  207,  275,  326,  207,  214,  283,
      391,  326,  333,  214,  185,  185,  251,  517,  573,  283,
      391,  333,  573,  633,  333,  233,  408,  675,  408,  456,
      456,  533,  456,  533,  333,  517,  561,  633,  642,  676,
      677,  678,  561,  642,  679,  680,  681,  682,  683,  684,

      685,  684,  686,  687,  688,  689,  690,  691,  692,  693,
      694,  695,  696,  697,  698,  699,  700,  701,  702,  703,
      704,  705,  706,  707,  708,  709,  711,  714,  716,  719,
      720,  721,  723,  726,  729,  730,  731,  732,  733,  734,
      735,  693,  737,  738,  739,  697,  740,  741,  742,  743,
      744,  745,  746,  747,  748,  749,  750,  751,  752,  753,
      754,  755,  756,  757,  758,  759,  760,  762,  763,  764,
      765,  766,  767,  768,  769,  771,  772,  773,  774,  775,
      776,  777,  779,  780,  781,  782,  783,  785,  786,  787,
      788,  789,  790,  791,  792,  793,  794,  795,  796,  797,

      798,  799,  800,  801,  802,  803,  804,  805,  806,  808,
      809,  810,  812,  813,  814,  815,  816,  818,  819,  820,
      821,  823,  824,  827,  828,  829,  831,  832,  834,  835,
      837,  838,  839,  840,  841,  842,  843,  845,  846,  847,
      848,  849,  850,  851,  852,  853,  854,  855,  857,  858,
      860,  861,  862,  863,  864,  865,  867,  868,  869,  870,
      871,  872,  873,  874,  875,  876,  877,  878,  879,  880,
      882,  883,  884,  885,  883,  886,  887,  888,  889,  890,
      891,  892,  893,  894,  895,  896,  897,  898,  900,  901,
      902,  903,  904,  905,  906,  907,  910,  911,  914,  915,

      916,  917,  918,  919,  920,  921,  922,  923,  921,  924,
      925,  926,  927,  928,  929,  930,  931,  933,  935,  936,
      938,  940,  941,  944,  945,  947,  948,  949,  950,  953,
      954,  955,  956,  957,  958,  959,  960,  962,  964,  967,
      970,  971,  972,  973,  974,  975,  977,  978,  979,  981,
      982,  984,  985,  986,  987,  988,  989,  990,  991,  992,
      993,  994,  996,  997,  998,  999, 1000, 1001, 1002, 1004,
     1006, 1011, 1012, 1013, 1006, 1014, 1015, 1016, 1017, 1018,
     1019, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1031,
     1032, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042,

     1043, 1044, 1045, 1046, 1047, 1048, 1051, 1052, 1053, 1055,
     1057, 1058, 1059, 1060, 1060, 1062, 1063, 1065, 1066, 1067,
     1068, 1069, 1070, 1072, 1074, 1076, 1077, 1078, 1079, 1082,
     1083, 1084, 1085, 1088, 1089, 1090, 1091, 1093, 1094, 1095,
     1097, 1098, 1100, 1101, 1102, 1104, 1105, 1106, 1107, 1109,
     1110, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120,
     1121, 1122, 1124, 1125, 1126, 1127, 1129, 1130, 1132, 1133,
     1134, 1135, 1136, 1137, 1139, 1140, 1141, 1143, 1146, 1147,
     1148, 1150, 1151, 1152, 1154, 1160, 1162, 1163, 1164, 1168,
     1169, 1170, 1171, 1172, 1173, 1175, 1176, 1179, 1186,  663,

      662, 1186, 1187, 1187,  661,  660, 1187, 1188, 1188, 1189,
     1189, 1189,  659, 1189, 1190, 1190, 1190, 1190, 1190, 1190,
     1191, 1191, 1191, 1191, 1191, 1191,  658,  657,  656,  655,
      654,  653,  652,  651,  650,  649,  648,  647,  645,  644,
      643,  641,  640,  639,  638,  637,  636,  635,  634,  632,
      631,  630,  628,  627,  626,  625,  624,  623,  622,  621,
      620,  619,  618,  617,  616,  615,  614,  613,  612,  611,
      610,  609,  608,  606,  605,  604,  603,  602,  601,  600,
      599,  598,  596,  595,  594,  593,  591,  590,  589,  588,
      587,  586,  585,  584,  583,  582,  581,  580,  579,  578,

      577,  576,  575,  574,  572,  571,  570,  569,  568,  567,
      566,  564,  563,  562,  560,  559,  558,  557,  556,  555,
      554,  553,  550,  549,  548,  547,  546,  545,  544,  543,
      542,  541,  540,  538,  537,  536,  535,  534,  531,  530,
      529,  528,  527,  526,  525,  524,  523,  522,  521,  519,
      518,  516,  515,  513,  512,  511,  510,  509,  508,  507,
      506,  505,  504,  503,  502,  501,  500,  499,  498,  497,
      496,  495,  494,  493,  491,  490,  489,  488,  487,  486,
      485,  484,  483,  482,  481,  480,  479,  477,  476,  475,
      474,  473,  471,  470,  469,  468,  467,  466,  465,  464,

      463,  462,  460,  459,  458,  457,  455,  454,  453,  452,
      451,  449,  448,  447,  446,  445,  444,  443,  442,  441,
      440,  439,  438,  437,  435,  434,  433,  432,  431,  430,
      429,  428,  427,  425,  423,  422,  421,  420,  419,  418,
      417,  416,  414,  413,  412,  411,  410,  409,  406,  405,
      404,  403,  402,  401,  400,  399,  398,  397,  396,  395,
      394,  393,  390,  389,  388,  387,  386,  385,  384,  383,
      382,  381,  380,  379,  378,  377,  376,  375,  374,  373,
      372,  371,  369,  367,  366,  365,  364,  360,  359,  357,
      356,  355,  354,  350,  349,  348,  347,  346,  345,  344,

      343,  342,  341,  340,  339,  338,  337,  334,  332,  331,
      330,  329,  328,  327,  324,  323,  322,  321,  318,  317,
      316,  315,  314,  313,  312,  311,  309,  308,  307,  306,
      305,  304,  303,  301,  300,  299,  298,  297,  296,  295,
      294,  293,  292,  291,  290,  289,  288,  287,  286,  285,
      284,  282,  281,  280,  279,  278,  277,  276,  274,  273,
      271,  269,  268,  266,  265,  264,  263,  262,  261,  260,
      259,  258,  256,  252,  250,  249,  248,  247,  246,  245,
      244,  243,  242,  241,  240,  237,  236,  235,  234,  232,
      231,  230,  228,  227,  226,  225,  224,  223,  222,  220,

      219,  218,  217,  216,  215,  213,  212,  211,  210,  209,
      208,  206,  205,  204,  203,  202,  200,  199,  198,  197,
      196,  195,  194,  193,  192,  191,  190,  189,  188,  183,
      182,  181,  180,  177,  176,  175,  173,  172,  170,  169,
      168,  167,  166,  165,  163,  161,  160,  159,  158,  155,
      154,  153,  152,  151,  150,  149,  147,  146,  145,  144,
      141,  140,  138,  137,  135,  132,  131,  130,  129,  127,
      126,  125,  124,  122,  121,  120,  119,  118,  117,  115,
      114,  113,  112,  110,  109,  107,  106,  105,  104,  103,
      102,  101,  100,   98,   97,   91,   88,   87,   86,   82,

       81,   80,   76,   75,   74,   68,   66,   65,   63,   60,
       58,   57,   56,   55,   52,   47,   45,   17,    6,    3,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185, 1185,
     1185, 1185
    } ;

static yyconst flex_int16_t yy_rule_linenum[209] =
    {   0,
       43,   44,   46,   48,   49,   50,   51,   52,   54,   55,
       56,   58,   59,   60,   61,   62,   63,   65,   67,   69,
       70,   71,   72,   73,   74,   75,   76,   77,   79,   80,
       81,   82,   84,   85,   86,   87,   89,   90,   91,   92,
       93,   94,   95,   96,   97,   99,  100,  101,  102,  103,
      104,  105,  107,  108,  110,  111,  112,  113,  114,  115,
      116,  117,  118,  119,  120,  121,  122,  123,  125,  126,
      127,  129,  130,  131,  132,  133,  134,  135,  136,  137,
      138,  139,  140,  142,  144,  145,  146,  147,  148,  149,
      151,  152,  153,  154,  155,  156,  157,  158,  159,  161,

      162,  163,  164,  165,  166,  167,  168,  169,  170,  171,
      172,  173,  174,  175,  176,  177,  178,  179,  180,  181,
      182,  183,  184,  185,  186,  187,  188,  189,  190,  191,
      192,  193,  195,  196,  197,  198,  199,  200,  201,  202,
      203,  204,  205,  206,  207,  208,  209,  210,  211,  212,
      213,  214,  215,  216,  217,  218,  219,  220,  221,  222,
      223,  224,  225,  226,  227,  228,  229,  230,  231,  232,
      233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
      243,  244,  245,  246,  247,  248,  249,  250,  251,  252,
      253,  254,  255,  256,  257,  258,  259,  260,  261,  262,

      263,  267,  268,  269,  270,  273,  274,  275
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "parser/cmdoptions.l"
/******************************************************************************
* Copyright 2015-2022 Xilinx, Inc.
* Copyright 2022-2023 Advanced Micro Devices, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
******************************************************************************/
/* This is the lexer/flexer input file, that tokenizes the register initialization file */
/* Run the cmdoptions.y file first through bison to generate the regidit.tab.hpp file, which is included herein */
/* Then run this file through flex to generate the cmdoptions.yy.c source code */
#line 23 "parser/cmdoptions.l"
 #include <stdio.h>
 #include "cmdoptionsscanner.h"
 #include "cmdoptions.tab.hpp"
 typedef CO::BisonParser::token tok;
#line 32 "parser/cmdoptions.l"
     # define YY_USER_ACTION  yylloc->columns (yyleng);
#line 1263 "bisonflex/cmdoptions.yy.cpp"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
#include <unistd.h>
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */
/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */
/* %if-bison-bridge */
/* %endif */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */
/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* %endif */
/* %if-c++-only C++ definition */
#define ECHO LexerOutput( yytext, yyleng )
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
\
/* %if-c++-only C++ definition \ */\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
/* %endif */
/* %if-c++-only */
#define YY_FATAL_ERROR(msg) LexerError( msg )
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */
/* %endif */
/* %if-c++-only C++ definition */
#define YY_DECL int yyFlexLexer::yylex()
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
/* %% [7.0] user's declarations go here */
#line 35 "parser/cmdoptions.l"



   yylloc->step ();




#line 1429 "bisonflex/cmdoptions.yy.cpp"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			yyin = & std::cin;
/* %endif */

		if ( ! yyout )
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			yyout = & std::cout;
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1186 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1185 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				std::cerr << "--scanner backing up\n";
			else if ( yy_act < 209 )
				std::cerr << "--accepting rule at line " << yy_rule_linenum[yy_act] <<
				         "(\"" << yytext << "\")\n";
			else if ( yy_act == 209 )
				std::cerr << "--accepting default rule (\"" << yytext << "\")\n";
			else if ( yy_act == 210 )
				std::cerr << "--(end of buffer or a NUL)\n";
			else
				std::cerr << "--EOF (start condition " << YY_START << ")\n";
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 43 "parser/cmdoptions.l"
{ comment(); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 44 "parser/cmdoptions.l"
/* ignore */;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 46 "parser/cmdoptions.l"
yylval->number=strtoul(yytext+2,NULL,16); return tok::HEXVALUE;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 48 "parser/cmdoptions.l"
return tok::_IMAGE;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 49 "parser/cmdoptions.l"
return tok::_FILL;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 50 "parser/cmdoptions.l"
return tok::_O_TOK;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 51 "parser/cmdoptions.l"
return tok::I;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 52 "parser/cmdoptions.l"
return tok::_P_TOK;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 54 "parser/cmdoptions.l"
return tok::_W;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 55 "parser/cmdoptions.l"
return tok::ON;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 56 "parser/cmdoptions.l"
return tok::OFF;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 58 "parser/cmdoptions.l"
return tok::_LOG;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 59 "parser/cmdoptions.l"
return tok::ERROR;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 60 "parser/cmdoptions.l"
return tok::WARNING;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 61 "parser/cmdoptions.l"
return tok::INFO;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 62 "parser/cmdoptions.l"
return tok::DEBUG;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 63 "parser/cmdoptions.l"
return tok::TRACE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 65 "parser/cmdoptions.l"
return tok::_BIF_HELP;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 67 "parser/cmdoptions.l"
return tok::_SYNCFLAG;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 69 "parser/cmdoptions.l"
return tok::_ENCRYPT;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 70 "parser/cmdoptions.l"
return tok::BBRAM;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 71 "parser/cmdoptions.l"
return tok::EFUSE;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 72 "parser/cmdoptions.l"
return tok::HMAC;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 73 "parser/cmdoptions.l"
return tok::HMAC;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 74 "parser/cmdoptions.l"
return tok::STARTCBC;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 75 "parser/cmdoptions.l"
return tok::STARTCBC;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 76 "parser/cmdoptions.l"
return tok::KEY0;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 77 "parser/cmdoptions.l"
return tok::KEY0;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 79 "parser/cmdoptions.l"
return tok::_SPLIT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 80 "parser/cmdoptions.l"
return tok::_PROCESS_BITSTREAM;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 81 "parser/cmdoptions.l"
return tok::MCS;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 82 "parser/cmdoptions.l"
return tok::BIN;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 84 "parser/cmdoptions.l"
return tok::_DUAL_QSPI_MODE;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 85 "parser/cmdoptions.l"
return tok::_DUAL_OSPI_MODE;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 86 "parser/cmdoptions.l"
return tok::PARALLEL;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 87 "parser/cmdoptions.l"
return tok::STACKED;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 89 "parser/cmdoptions.l"
return tok::EQUALS;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 90 "parser/cmdoptions.l"
return tok::COMMA;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 91 "parser/cmdoptions.l"
return tok::_DEBUG_TOK;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 92 "parser/cmdoptions.l"
return tok::_DUMP;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 93 "parser/cmdoptions.l"
return tok::DUMP_PLM;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 94 "parser/cmdoptions.l"
return tok::DUMP_PMC_CDO;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 95 "parser/cmdoptions.l"
return tok::DUMP_BOOT_FILES;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 96 "parser/cmdoptions.l"
return tok::DUMP_SLAVE_PDIS;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 97 "parser/cmdoptions.l"
return tok::DUMP_PUF_PDI;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "parser/cmdoptions.l"
return tok::_DUMP_DIR;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 100 "parser/cmdoptions.l"
return tok::_PUF;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 101 "parser/cmdoptions.l"
return tok::_LEGACY;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 102 "parser/cmdoptions.l"
return tok::_PADIMAGEHEADER;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 103 "parser/cmdoptions.l"
return tok::_EFUSEPPKBITS;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 104 "parser/cmdoptions.l"
return tok::_EFUSEPUFBITS;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 105 "parser/cmdoptions.l"
return tok::_GENERATE_HASHES;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 107 "parser/cmdoptions.l"
return tok::_SECUREDEBUG;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 108 "parser/cmdoptions.l"
return tok::_AUTHJTAG;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 110 "parser/cmdoptions.l"
return tok::_GENERATE_KEYS;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 111 "parser/cmdoptions.l"
return tok::AUTH;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 112 "parser/cmdoptions.l"
return tok::PEM;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 113 "parser/cmdoptions.l"
return tok::RSA;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 114 "parser/cmdoptions.l"
return tok::GREY;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 115 "parser/cmdoptions.l"
return tok::METAL;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 116 "parser/cmdoptions.l"
return tok::ECDSA;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 117 "parser/cmdoptions.l"
return tok::ECDSA;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 118 "parser/cmdoptions.l"
return tok::ECDSAP521;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 119 "parser/cmdoptions.l"
return tok::LMS;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 120 "parser/cmdoptions.l"
return tok::LMS_SHA256;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 121 "parser/cmdoptions.l"
return tok::LMS_SHAKE256;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 122 "parser/cmdoptions.l"
return tok::HSS_SHA256;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 123 "parser/cmdoptions.l"
return tok::HSS_SHAKE256;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 125 "parser/cmdoptions.l"
return tok::_NONBOOTING;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 126 "parser/cmdoptions.l"
return tok::_SPKSIGNATURE;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 127 "parser/cmdoptions.l"
return tok::_PACKAGENAME;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 129 "parser/cmdoptions.l"
return tok::_ARCH;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 130 "parser/cmdoptions.l"
return tok::ZYNQ;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 131 "parser/cmdoptions.l"
return tok::ZYNQMP;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 132 "parser/cmdoptions.l"
return tok::VERSAL;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 133 "parser/cmdoptions.l"
return tok::FPGA;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 134 "parser/cmdoptions.l"
return tok::VERSALNET;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 135 "parser/cmdoptions.l"
return tok::TELLURIDE;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 136 "parser/cmdoptions.l"
return tok::VERSAL_2VE_2VM;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 137 "parser/cmdoptions.l"
return tok::LASSEN;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 138 "parser/cmdoptions.l"
return tok::LASSEN_DL9;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 139 "parser/cmdoptions.l"
return tok::SPARTANUP;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 140 "parser/cmdoptions.l"
return tok::SPARTANUP;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 142 "parser/cmdoptions.l"
return tok::_R;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 144 "parser/cmdoptions.l"
return tok::_READ;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 145 "parser/cmdoptions.l"
return tok::READ_BH;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 146 "parser/cmdoptions.l"
return tok::READ_IHT;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 147 "parser/cmdoptions.l"
return tok::READ_IH;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 148 "parser/cmdoptions.l"
return tok::READ_PHT;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 149 "parser/cmdoptions.l"
return tok::READ_AC;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 151 "parser/cmdoptions.l"
return tok::_AUTH_OPTIMIZATION;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 152 "parser/cmdoptions.l"
return tok::_VERIFYKDF;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 153 "parser/cmdoptions.l"
return tok::_VERIFY;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 154 "parser/cmdoptions.l"
return tok::_ZYNQMPENCRDUMP;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 155 "parser/cmdoptions.l"
return tok::_NOAUTHBLOCKS;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 156 "parser/cmdoptions.l"
return tok::_ZYNQMPES1;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 157 "parser/cmdoptions.l"
return tok::_OVERLAYCDO;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 158 "parser/cmdoptions.l"
return tok::_OUT_TYPE;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 159 "parser/cmdoptions.l"
return tok::_TLBIN;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 161 "parser/cmdoptions.l"
return tok::_H;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 162 "parser/cmdoptions.l"
return tok::_H;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 163 "parser/cmdoptions.l"
return tok::HBIFHELP;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 164 "parser/cmdoptions.l"
return tok::HARCH;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 165 "parser/cmdoptions.l"
return tok::HAUTHOPT;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 166 "parser/cmdoptions.l"
return tok::HIMAGE;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 167 "parser/cmdoptions.l"
return tok::HFILL;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 168 "parser/cmdoptions.l"
return tok::HO;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 169 "parser/cmdoptions.l"
return tok::HP;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 170 "parser/cmdoptions.l"
return tok::HW;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 171 "parser/cmdoptions.l"
return tok::HEFUSEPPKBITS;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 172 "parser/cmdoptions.l"
return tok::HGENHASHES;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 173 "parser/cmdoptions.l"
return tok::HLEGACY;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 174 "parser/cmdoptions.l"
return tok::HPADHDR;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 175 "parser/cmdoptions.l"
return tok::H_SPKSIGN;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 176 "parser/cmdoptions.l"
return tok::HPACKAGE;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 177 "parser/cmdoptions.l"
return tok::HENCRYPT;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 178 "parser/cmdoptions.l"
return tok::HGENKEYS;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 179 "parser/cmdoptions.l"
return tok::HDQSPI;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 180 "parser/cmdoptions.l"
return tok::HLOG;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 181 "parser/cmdoptions.l"
return tok::HZYNQMPES1;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 182 "parser/cmdoptions.l"
return tok::HPROCESSBIT;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 183 "parser/cmdoptions.l"
return tok::HNONBOOTING;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 184 "parser/cmdoptions.l"
return tok::HENCRDUMP;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 185 "parser/cmdoptions.l"
return tok::HVERIFY;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 186 "parser/cmdoptions.l"
return tok::HVERIFYKDF;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 187 "parser/cmdoptions.l"
return tok::HSECUREDEBUG;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 188 "parser/cmdoptions.l"
return tok::HSECUREDEBUG;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 189 "parser/cmdoptions.l"
return tok::HREAD;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 190 "parser/cmdoptions.l"
return tok::HDUMP;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 191 "parser/cmdoptions.l"
return tok::HDUMPDIR;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 192 "parser/cmdoptions.l"
return tok::HOVLCDO;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 193 "parser/cmdoptions.l"
return tok::HOUTTYPE;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 195 "parser/cmdoptions.l"
return tok::H_BIF_AARCH32;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 196 "parser/cmdoptions.l"
return tok::H_BIF_BIGENDIAN;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 197 "parser/cmdoptions.l"
return tok::H_BIF_BOOTCONFIG;
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 198 "parser/cmdoptions.l"
return tok::H_BIF_COPY;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 199 "parser/cmdoptions.l"
return tok::H_BIF_CORE;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 200 "parser/cmdoptions.l"
return tok::H_BIF_DELAY_HANDOFF;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 201 "parser/cmdoptions.l"
return tok::H_BIF_DELAY_LOAD;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 202 "parser/cmdoptions.l"
return tok::H_BIF_FILE;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 203 "parser/cmdoptions.l"
return tok::H_BIF_ID;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 204 "parser/cmdoptions.l"
return tok::H_BIF_IMAGE;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 205 "parser/cmdoptions.l"
return tok::H_BIF_METAHDR;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 206 "parser/cmdoptions.l"
return tok::H_BIF_NAME;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 207 "parser/cmdoptions.l"
return tok::H_BIF_PARTITION;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 208 "parser/cmdoptions.l"
return tok::H_BIF_PARENTID;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 209 "parser/cmdoptions.l"
return tok::H_BIF_SLR;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 210 "parser/cmdoptions.l"
return tok::H_BIF_TYPE;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 211 "parser/cmdoptions.l"
return tok::H_BIF_KEYSRC;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 212 "parser/cmdoptions.l"
return tok::H_BIF_INIT;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 213 "parser/cmdoptions.l"
return tok::H_BIF_UDFBH;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 214 "parser/cmdoptions.l"
return tok::H_BIF_AES;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 215 "parser/cmdoptions.l"
return tok::H_BIF_PPK;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 216 "parser/cmdoptions.l"
return tok::H_BIF_PSK;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 217 "parser/cmdoptions.l"
return tok::H_BIF_SPK;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 218 "parser/cmdoptions.l"
return tok::H_BIF_SSK;
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 219 "parser/cmdoptions.l"
return tok::H_BIF_SPKSIGN;
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 220 "parser/cmdoptions.l"
return tok::H_BIF_HDRSIGN;
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 221 "parser/cmdoptions.l"
return tok::H_BIF_BOOTIMAGE;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 222 "parser/cmdoptions.l"
return tok::H_BIF_BL;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 223 "parser/cmdoptions.l"
return tok::H_BIF_PLDATA;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 224 "parser/cmdoptions.l"
return tok::H_BIF_ENCR;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 225 "parser/cmdoptions.l"
return tok::H_BIF_PID;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 226 "parser/cmdoptions.l"
return tok::H_BIF_AUTH;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 227 "parser/cmdoptions.l"
return tok::H_BIF_TCMBOOT;
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 228 "parser/cmdoptions.l"
return tok::H_BIF_OPTIONALDATA;
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 229 "parser/cmdoptions.l"
return tok::H_BIF_CHKSM;
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 230 "parser/cmdoptions.l"
return tok::H_BIF_POWNER;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 231 "parser/cmdoptions.l"
return tok::H_BIF_POWNER;
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 232 "parser/cmdoptions.l"
return tok::H_BIF_PRESIGN;
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 233 "parser/cmdoptions.l"
return tok::H_BIF_UDF;
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 234 "parser/cmdoptions.l"
return tok::H_BIF_XIP;
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 235 "parser/cmdoptions.l"
return tok::H_BIF_ALIGN;
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 236 "parser/cmdoptions.l"
return tok::H_BIF_OFFSET;
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 237 "parser/cmdoptions.l"
return tok::H_BIF_RES;
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 238 "parser/cmdoptions.l"
return tok::H_BIF_LOAD;
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 239 "parser/cmdoptions.l"
return tok::H_BIF_STARTUP;
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 240 "parser/cmdoptions.l"
return tok::H_BIF_KEYSRCENCR;
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 241 "parser/cmdoptions.l"
return tok::H_BIF_FSBLCFG;
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 242 "parser/cmdoptions.l"
return tok::H_BIF_BOOTDEV;
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 243 "parser/cmdoptions.l"
return tok::H_BIF_DESTCPU;
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 244 "parser/cmdoptions.l"
return tok::H_BIF_DESTDEV;
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 245 "parser/cmdoptions.l"
return tok::H_BIF_EL;
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 246 "parser/cmdoptions.l"
return tok::H_BIF_TZ;
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 247 "parser/cmdoptions.l"
return tok::H_BIF_AUTHPARAM;
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 248 "parser/cmdoptions.l"
return tok::H_BIF_BHKEY;
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 249 "parser/cmdoptions.l"
return tok::H_BIF_PFW;
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 250 "parser/cmdoptions.l"
return tok::H_BIF_BLOCKS;
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 251 "parser/cmdoptions.l"
return tok::H_BIF_BHIV;
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 252 "parser/cmdoptions.l"
return tok::H_BIF_METAL;
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 253 "parser/cmdoptions.l"
return tok::H_BIF_ELYHNDOFF;
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 254 "parser/cmdoptions.l"
return tok::H_BIF_HIVEC;
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 255 "parser/cmdoptions.l"
return tok::H_BIF_BHSIGN;
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 256 "parser/cmdoptions.l"
return tok::H_SPLIT;
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 257 "parser/cmdoptions.l"
return tok::H_BIF_BOOTVEC;
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 258 "parser/cmdoptions.l"
return tok::H_BIF_PUFDATA;
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 259 "parser/cmdoptions.l"
return tok::H_DPACM_ENABLE;
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 260 "parser/cmdoptions.l"
return tok::H_BIF_USERKEYS;
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 261 "parser/cmdoptions.l"
return tok::HVN_BIF_PCR;
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 262 "parser/cmdoptions.l"
return tok::HVN_BIF_PCR_MINDEX;
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 263 "parser/cmdoptions.l"
return tok::HV_BIF_IMAGESTORE;
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 267 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext);         return tok::HEXSTRING;
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 268 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext);  return tok::IDENTIFIER;
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 269 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext);    return tok::FILENAME;
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 270 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext+1); yylval->cstring[strlen(yytext)-2]=0; return tok::QFILENAME;
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 273 "parser/cmdoptions.l"
yylloc->step ();
	YY_BREAK
case 207:
/* rule 207 can match eol */
YY_RULE_SETUP
#line 274 "parser/cmdoptions.l"
yylloc->lines (yyleng); yylloc->step ();
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 275 "parser/cmdoptions.l"
LOG_ERROR("Unknown option on command line: %s\n",yytext);
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 276 "parser/cmdoptions.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2585 "bisonflex/cmdoptions.yy.cpp"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	cmdoptionsfree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	cmdoptionsfree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
int yyFlexLexer::LexerInput( char* buf, int /* max_size */ )
#else
int yyFlexLexer::LexerInput( char* buf, int max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, int size )
{
	(void) yyout->write( buf, size );
}
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
int yyFlexLexer::yy_get_next_buffer()
/* %endif */
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					cmdoptionsrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) cmdoptionsrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

/* %endif */
/* %if-c++-only */
    yy_state_type yyFlexLexer::yy_get_previous_state()
/* %endif */
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1186 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
/* %endif */
{
	register int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1186 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1185);

	return yy_is_jam ? 0 : yy_current_state;
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yyunput( int c, register char* yy_bp)
/* %endif */
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    int yyFlexLexer::yyinput()
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */

	return c;
}
/* %if-c-only */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yyrestart( std::istream* input_file )
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_load_buffer_state()
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) cmdoptionsalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) cmdoptionsalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		cmdoptionsfree((void *) b->yy_ch_buf  );

	cmdoptionsfree((void *) b  );
}

/* %if-c-only */
/* %endif */

/* %if-c++-only */

extern "C" int isatty (int );

/* %endif */

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */
/* %endif */
/* %if-c++-only */
	b->yy_is_interactive = 0;
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yypop_buffer_state (void)
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yyensure_buffer_stack(void)
/* %endif */
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)cmdoptionsalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)cmdoptionsrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_push_state( int new_state )
/* %endif */
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) cmdoptionsalloc(new_size  );

		else
			(yy_start_stack) = (int *) cmdoptionsrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_pop_state()
/* %endif */
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    int yyFlexLexer::yy_top_state()
/* %endif */
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* %if-reentrant */
/* %endif */
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *cmdoptionsalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *cmdoptionsrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void cmdoptionsfree (void * ptr )
{
	free( (char *) ptr );	/* see cmdoptionsrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 276 "parser/cmdoptions.l"




void CO::FlexScanner::comment()
{
    char c, c1;
    loop:
        while ((c = yyinput()) != '*' && c != 0) 
        {
            // putchar(c);
        }

    if ((c1 = yyinput()) != '/' && c != 0)
    {
        unput(c1);
        goto loop;
    }
}

